=====================================
``psyclone.psyir.nodes.array_member``
=====================================

.. automodule:: psyclone.psyir.nodes.array_member

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.array_member


Classes
=======

- :py:class:`ArrayMember`:
  Node representing an access to the element(s) of an array that is a


.. autoclass:: ArrayMember
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ArrayMember
      :parts: 1
